@@ -109,10 +109,6 @@ class Server(Resource):
     def region(self):
         return self.__region
 
-    @lazy_property
-    def platform(self):
-        return self.__platform
-
     @lazy_property
     def provider_product_id(self):
         return self.__provider_product_id
@@ -125,6 +121,10 @@ class Server(Resource):
     def provider_id(self):
         return self.__provider_id
 
+    @lazy_property
+    def product(self):
+        return self.__product
+
     @lazy_property
     def start_date(self):
         return self.__start_date
